pub struct FeatureSku {
pub seller_sku: Option<String>,
pub fn_sku: Option<String>,
pub asin: Option<String>,
pub sku_count: Option<f32>,
pub overlapping_skus: Option<Vec<String>>,
}Expand description
FeatureSku : Information about an SKU, including the count available, identifiers, and a list of overlapping SKUs that share the same inventory pool.
Fields
seller_sku: Option<String>Used to identify an item in the given marketplace. SellerSKU is qualified by the seller’s SellerId, which is included with every operation that you submit.
fn_sku: Option<String>The unique SKU used by Amazon’s fulfillment network.
asin: Option<String>The Amazon Standard Identification Number (ASIN) of the item.
sku_count: Option<f32>The number of SKUs available for this service.
overlapping_skus: Option<Vec<String>>Other seller SKUs that are shared across the same inventory.
Implementations
sourceimpl FeatureSku
impl FeatureSku
sourcepub fn new() -> FeatureSku
pub fn new() -> FeatureSku
Information about an SKU, including the count available, identifiers, and a list of overlapping SKUs that share the same inventory pool.